@@ -63,8 +63,8 @@ class DataTable(Element):
             Leave it None if you're sure there is only one page of data.
     """
     def __init__(self, title="", columns=[], data=[], row_actions=[],
-            table_actions=[], on_data=None, id=None):
+            table_actions=[], filter_form=None, on_data=None, id=None):
         on_data_uuid = callbackRegistry.uuid_for_callback(on_data)
         super().__init__('DataTable', title=title, columns=columns, data=data,
-            row_actions=row_actions, table_actions=table_actions, on_data=on_data_uuid, id=id)
+            row_actions=row_actions, table_actions=table_actions, filter_form=filter_form, on_data=on_data_uuid, id=id)
 
